#
# spec file for package zynaddsubfx
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           zynaddsubfx
Version:        3.0.6
Release:        bp156.1.6
Summary:        A Real-Time Software Synthesizer for Linux
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Midi
URL:            https://zynaddsubfx.sourceforge.io/
Source0:        https://sourceforge.net/projects/%{name}/files/%{name}/%{version}/%{name}-%{version}.tar.bz2
Patch0:         zynaddsubfx-buildflags.patch
Patch1:         fix-missing-include.patch
BuildRequires:  cmake
BuildRequires:  dssi
BuildRequires:  fltk-devel
BuildRequires:  gcc-c++
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(dssi)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(fftw3f)
BuildRequires:  pkgconfig(fftw3l)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(liblo)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(mxml)
BuildRequires:  pkgconfig(ntk) >= 1.3.1001
BuildRequires:  pkgconfig(ntk_gl) >= 1.3.1001
BuildRequires:  pkgconfig(ntk_images) >= 1.3.1001
BuildRequires:  pkgconfig(portaudio-2.0)
BuildRequires:  pkgconfig(xpm)
BuildRequires:  pkgconfig(zlib)
Provides:       ZynAddSubFX = %{version}
Obsoletes:      ZynAddSubFX < %{version}
Requires:       %{name}-common = %{version}

%description
zynaddsubfx is a many-featured real-time software synthesizer for
Linux.	Features include polyphony and multitimbrel and microtonal
capabilities. It includes randomness of some parameters, which can make
warm sounds, like analog synthesizers.	This program has system and
insertion effects, too.

%package bash-completion
Summary:        Bash completion for ZynAddSubFX
Requires:       %{name} = %{version}
Requires:       bash

%description bash-completion
Bash command line completion support for ZynAddSubFX.

%package common
Summary:        Common files for ZynAddSubFX synthesizers
Group:          Productivity/Multimedia/Sound/Midi
Provides:       ZynAddSubFX-common = %{version}
Obsoletes:      ZynAddSubFX-common < %{version}
BuildArch:      noarch

%description common
zynaddsubfx is a many-featured real-time software synthesizer for
Linux.	Features include polyphony and multitimbrel and microtonal
capabilities. It includes randomness of some parameters, which can make
warm sounds, like analog synthesizers.	This program has system and
insertion effects, too.

These are files common to the gui and dssi,lv2 and vst plugins.

%package dssi
Summary:        Real-time software synthesizer, DSSI Plugin version
Group:          Productivity/Multimedia/Sound/Midi
Requires:       %{name}-common = %{version}-%{release}
Requires:       dssi

%description dssi
zynaddsubfx is a many-featured real-time software synthesizer for
Linux.	Features include polyphony and multitimbrel and microtonal
capabilities. It includes randomness of some parameters, which can make
warm sounds, like analog synthesizers.	This program has system and
insertion effects, too.

This package includes the DSSI zynaddsubfx synthesizer plugins.

%package lv2
Summary:        Real-time software synthesizer, LV2 Plugin version
Group:          Productivity/Multimedia/Sound/Midi
Requires:       %{name}-common = %{version}-%{release}

%description lv2
zynaddsubfx is a many-featured real-time software synthesizer for
Linux.	Features include polyphony and multitimbrel and microtonal
capabilities. It includes randomness of some parameters, which can make
warm sounds, like analog synthesizers.	This program has system and
insertion effects, too.

This package includes the LV2 zynaddsubfx synthesizer plugins.

%package vst
Summary:        Real-time software synthesizer, VST Plugin version
Group:          Productivity/Multimedia/Sound/Midi
Requires:       %{name}-common = %{version}-%{release}

%description vst
zynaddsubfx is a many-featured real-time software synthesizer for
Linux.	Features include polyphony and multitimbrel and microtonal
capabilities. It includes randomness of some parameters, which can make
warm sounds, like analog synthesizers.	This program has system and
insertion effects, too.

This package includes the VST zynaddsubfx synthesizer plugins.

%prep
%autosetup -p1

%build
%cmake \
      -DDefaultOutput=jack \
      -DNoNeonPlease:BOOL=ON \
      -DOssEnable:BOOL=FALSE \
%ifarch %{ix86} x86_64
      -DX86Build=ON \
%endif
      -DPluginLibDir:STRING=%{_lib}

pushd src/Tests/CMakeFiles
for i in `find . -name link.txt` ;do sed -i 's/--no-as-needed -lpthread/--no-as-needed -lpthread -lfltk/' ${i} ;done
popd

make %{?_smp_mflags}

%install
make -C build DESTDIR=%{buildroot} install
%suse_update_desktop_file -r %{name}-alsa AudioVideo Music
%suse_update_desktop_file -r %{name}-jack AudioVideo Music
%suse_update_desktop_file -r %{name}-jack-multi AudioVideo Music
mkdir -p %{buildroot}%{_datadir}/zynaddsubfx
cp -a instruments/examples instruments/banks %{buildroot}%{_datadir}/zynaddsubfx

# We are including these in the common package below
rm -fr %{buildroot}%{_datadir}/doc/%{name}/
#Remove defective and useless zynaddsubfx-oss.desktop
rm -f %{buildroot}%{_datadir}/applications/zynaddsubfx-oss.desktop

%files
%{_bindir}/*
%{_datadir}/applications/%{name}*.desktop
%{_datadir}/pixmaps/zynaddsubfx.svg
%{_datadir}/pixmaps/zynaddsubfx.png

%files bash-completion
%{_datadir}/bash-completion/completions/zynaddsubfx

%files common
%license COPYING
%doc AUTHORS.txt NEWS.txt README.adoc
%{_datadir}/%{name}/

%files dssi
%{_libdir}/dssi/

%files lv2
%{_libdir}/lv2/

%files vst
%{_libdir}/vst/

%changelog
* Sat Apr  1 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add fix-missing-include.patch: Add missing #include <cstdint>
  exposed by gcc 13.
* Sun Mar 12 2023 Dave Plater <davejplater@gmail.com>
- Compensate for fltk's lack of pkgconfig file.Fixes Leap:15.5 build
* Thu Apr 14 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 3.0.6
  * Enhances watchpoint system for waveform views
  * Add anti-alias mode to add synth oscillator interpolation
  * Add 14 bit NRPN support for automations
  * Add Tanh, Cubic, and square distortions with additional shaping
    params
  * Add filter parameter smoothing
  * Add filter optional LPF to LFO
  * Add repeatable envelopes
  * Add LFO fade in
  * Add moog ladder filter
  * Add comb filter
  * Add BPM sync
  * Add latched key mode
  * Re-enable classic MIDI learn
  * Increase envelope time parameter resolution
  * Fix excessively loud volume bug in Part XML loader
  * Fix crash with gcc 10.x.x within file manager
  * Fix crash in erroneous patch load
  * Fix padsynth memory leak
  * Fix weird note-to-note portamento switches
  * Reduce fftw resolution from 64bit to 32bit
  * Remove Cxxtest dependency
  * Fix other bugs
- Subpackage for bash completions
- Rebased zynaddsubfx-buildflags.patch
- Drop upstream fixed zynaddsubfx-DPF.patch
* Fri Aug 30 2019 Fabio Pesari <fpesari@tuxfamily.org>
- Upgrade to release 3.0.5 and patch
- Upstream changes:
  * Add Stereo peaks for individual part metering
  * Change LFO frequency units to Hz (from unitless)
  * Enhance LFO delay parameter resolution and units (seconds)
  * Enhance global volume parameter resolution and units (dB)
  * Enhance part volume parameter resolution and units (dB)
  * Enhance sub synth volume parameter resolution and units (dB)
  * Enhance sub synth volume velocity sensing resolution
  * Fix zippering when changing master volume
  * Fix misaligned points in live envelope values
  * Fix possible crash when envelopes are provided invalid live data
  * Fix minor bugs
* Fri Mar 29 2019 plater <davejplater@gmail.com>
- Update to release 3.0.4 and rebase zynaddsubfx-buildflags.patch.
- Upstream changes:
  * Add scripting to zyn-fusion UI for automated screen capture
  * Add double click to reset sliders
  * Add random LFO to UI
  * Add compatibility with MXML 3.0
  * Enhance modulation volume parameter resolution
  * Enhance global volume parameter resolution
  * Enhance state variable filter interpolation
  * Change filter defaults for easier patch setup
  * Fix pops with note aftertouch
  * Fix pad synth export
  * Fix envelope watchpoint visualization
  * Fix .xlz load/save in fusion UI
  * Fix minor bugs
  * Added support for floating point notes via MIDI SYSEX.
* Mon Nov 19 2018 davejplater@gmail.com
- Require zynaddsubfx-common subpackage which is needed to run and
  fix boo#1116460.
- README.adoc states license is GPL 2+, updated %%License field.
* Tue Mar  6 2018 davejplater@gmail.com
- Update to release 3.0.3
- Remove incorporated zynaddsubfx-nodatetime.patch and rebase
  zynaddsubfx-buildflags.patch.
- Remove dependency on lash and add pulse audio support.
- Upstream changes since 3.0.1 :
  * Add bank search to FLTK/NTK GUI.
  * Add parallel padsynth sample generation.
  * Remove X11 dependency for non-GUI builds.
  * Fix crash when changing modulation types in running notes.
  * Fix loading filter parameters with older xml.
  * Fix effect saving when updating with zyn-fusion interface.
  * The build process is now reproducible.
  * Upgrade MIDI learn system to include host automations and macro
  learned controls.
  * Upgrade analog filter parameters to floating point resolution.
  * Add default values to OSC metadata.
  * Fix exit when closing zyn-fusion subprocess.
  * Fix crash with large number of pad synth samples.
  * Silence 0 volume effects.
  * Silence 0 volume add synth voices.
  * Fix minor bugs.
* Mon Dec  4 2017 crrodriguez@opensuse.org
- BuildRequires pkgconfig(xpm) not xorg-x11-devel
* Wed May 10 2017 davejplater@gmail.com
- Enable reproducible builds with zynaddsubfx-DPF.patch which fixes
  the generation of random output port values for lv2 plugins.
* Sat Apr 15 2017 davejplater@gmail.com
- Update to 3.0.1
- Added zynaddsubfx-nodatetime.patch to remove __DATE__ & __TIME__
- Upstream changes:
  * Fix bank screen with Zyn-Fusion
  * Fix crash on startup with GL 2.1 to 3.1
  * Fix UI Disconnection Bug
  * Add resizing to LV2 Zyn-Fusion
  * Fixes problems receiving MIDI over ALSA
  * Fixes crash when editing instrument description in Zyn-Fusion
  * Fixes crash when visualizing instruments in Zyn-Fusion
  * Add support for zest toolkit via Zyn-Fusion
  * Add watchpoints to env/LFO
  * Add Bank searching capabilities
  * Add Windows Midi Support
  * Add --midi-learn option for loading .xlz files
  * Add bank cache file
  * Add DC modulator type
  * Augment Existing 2.5.x OSC API metadata
  * Fix Envelope behavior on pre 2.4.4 patches
  * Fix ALSA hanging after suspend to ram
  * Fix Jack-Multi Crash
  * Fix FreeBSD compilation
  * Fix Windows compilation (via mingw64)
  * Fix unapplied microtonal settings on startup
* Thu Jan 19 2017 edogawa@aon.at
- Correct and improved copypasted summary texts of the three plugin
  subpackages
* Mon Aug 15 2016 davejplater@gmail.com
- Allow Leap:42.2 build to use non-ntk
* Thu Jun 30 2016 jengelh@inai.de
- Trim filelist, implicit parameters, stick to SUSE changelog
  format.
* Wed Jun 29 2016 davejplater@gmail.com
- Update to 2.5.4
- Moved plugins to correct library arch directory.
- Rebased zynaddsubfx-buildflags.patch
- Upstream changes:
  * Add realtime automation for subnote parameters
  * Add FLTK UI for LV2 plugins
  * Add support for '~' in bank paths
  * Fix VST crashes
  * Fix VST loading issues
  * Fix Microtonal copy/paste
  * Fix GCC 5.3.0 build issues
  * Fix autosave disable flag
  * Fix license headers
  * Fix plugin library directory
  * Fix uninitialized filter bug in subnote
  * Fix broken instrument send
* Wed Feb 10 2016 edogawa@aon.at
- update to version 2.5.3
  * updated zynaddsubfx-buildflags.patch
  * added subpackages for the new lv2 and vst plugin variants
  * Add autosave - Just in case of the rare crash, this can be a lifesaver
  * Add realtime filter parameter updates - For smoother, wilder filter tweaking
  * Add LFO random mode - adds sample and hold module integrated to the LFO,
    great for classic bleep-blop computer sounds (and a hundred other things)
  * Add more controls to DSSI plugin - For more knob turning sonic
    automation-exploration in DSSI plugin hosts
  * Add fixed frequency modulators - Easier FM operations
  * Add more reset states to knobs/sliders - double click will put it back to
    the default state, so you don’t need to be afraid of turning that knob, you
    can always go back.
  * dd PWM mod - Sweet sweeping from nasally to full bodied square waves
  * Fix Microtonal UI - if you do microtonal music, this is a huge deal!
  * Fix 'Add Bank' - easier organization for all your patches
  * Fix sustain bugs in 2.5.x series - So you can keep your feet below your
    keyboard to play more notes
  * Fix mem pool exhaustion bug - a boon to stability
  * Fix PADnote and Oscilgen copy/paste - for quicker sound design
  * Fix Midi unlearn - If you want to map that knob to something else...
  * Other miscellaneous bug fixes
  * New Presets in the 'olivers-other' bank.
* Sun Nov 22 2015 someuniquename@gmail.com
- Update to version 2.5.2
  * Add MIDI-Learn serialization
  * Add pink noise source
  * Restore mousewheel functionality
  * Restore bank LSB/MSB MIDI support
  * Improve tip windows
  * Improve oscdoc output
  * Restore External Oscillator/Modulator functionality
  * Remove remaining globals
  * Fix UI connection bugs
  * Added shortcuts on edit buttons
  * Other miscellaneous bug fixes
- Changes from version 2.5.0
  - Release 2.5.1 (4 Jul 2015)
    Add Colorized CMake Configuration
    Add PID option for jack
    Add OSC port option
    Add MIDI unlearn
    Add External UI Compilation
    Add Split Pitchbend
    Fix No Install NTK Build
    Fix Linker Issues
    Fix Presets/Copy/Paste
    Fix JACK Samplerate Check When JACK Isn't Running
    Remove Dump
    Remove Some Globals synth/uToB/bToU/etc
    Adjust BankUI Ascetic
    Other Misc Bug Fixes
- Changes from version 2.4.4
  - Release 2.5.0 (25 Feb 2015)
    Add Rtosc
    Add tlsf RT Memory Allocator
    Add --dump-oscdoc Flag
    Add OSC API
    Add Jack-OSC Support
    Add MIDI Learn
    Add Undo/Redo
    Add Multi-Out JACK Engine
    Add Multi-Out OSS Engine
    Add Top Level Window Icon
    Add OSS env Vars MIDI_DEVICE/DSP_DEVICE
    Add OSC port/PID file
    Remove Master::mutex
    Remove Almost All RT Unsafe Actions
    Disable (temporarily) DSSI
    Disable (temporarily) Copy/Paste
    Massive Internal Refactoring
* Tue Feb 17 2015 p.drouand@gmail.com
- Fix "Conflicts"
* Mon Feb 16 2015 p.drouand@gmail.com
- Fix license; GPL-2.0 only
* Mon Feb 16 2015 p.drouand@gmail.com
- Do zynaddsubfx conflict with ZynAddSubFx
* Sat Feb 14 2015 p.drouand@gmail.com
- Add zynaddsubfx-fix-GPL-license.patch; fix licensing conflict
  between GPL; There is an incompatibility here as this package
  mixes GPL-2.0 (only) with GPL-3.0 code:
  src/Nio/WavEngine.cpp (and other files) is GPL-2.0
  src/Nio/AlsaEngine.cpp and src/Nio/JackEngine.cpp is GPL-3.0+
* Mon Dec 15 2014 p.drouand@gmail.com
- ZynAddSubFx has been renamed by upstream in zynaddsubfx;
  this package provides/obsoletes ZynAddSubFx
- Split out data files into his own subpackage
- Split out the dssi module
* Sat Dec 13 2014 p.drouand@gmail.com
- Update to version 2.4.4
  + Add UI Mousewheel Support
  + Add Spectral Adjust Parameter Rescaling
  + Add Subnote filter smoothing
  + Add Unison derandomization options
  + Add NSM import/export
  + Add NTK UI compatiability
  + (re)Add OSX Support
  + Enhance performance of ADnote and SUBnote
  + Enhance Installer
  + Fix JACK2 specific segfault
  + Fix possible DSSI specific segfaults
  + Fix Unison Regressions
  + Documentation additions
  + Misc bug fixes
- Changes from version 2.4.3
  + Non  +session manager support
  + Midi aftertouch support
  + Documentation additions
  + Somewhat more sane Nio defaults
  + Misc bug fixes
- Changes from version 2.4.2
  + New IO backend support
  + MIDI bank select
  + Spike/Circle waveform
  + Faster subsynth
  + --exec-after-init flag
  + Version information compiled in
  + Misc Bug fixes
- Added patches
  + zynaddsubfx-array-overflow-fix.diff
  + zynaddsubfx-buildflags.patch
* Tue Jul 12 2011 pgajdos@novell.com
- build against fltk 1.3 (taken from git repository)
* Thu Sep 23 2010 davejplater@gmail.com
- Fixed all patches
* Sat Sep 18 2010 davejplater@gmail.com
- Update to version 2.4.1:
  * Adding APhaserand merging into Phaser
  * Azerty layout
  * XML bug fixes
  * Vibrato/Unison additions
  * Reverb rewrite
  * DSSI support enabled
  * other bugfixes
  * code cleanup
* Fri Jul 24 2009 tiwai@suse.de
- updated to version 2.4.0:
  * extended mono functionality
  * legato mode
  * export functionality on PADsynth
  * inclusion of LASH client
  * inclusion of DSSI audio output
  * enabled tooltips for knobs (both description and value tooltips)
  * added support for newer JACK api
  * added quertz support for virtual keyboard
  * started to encorperate cxxtest for unit testing
  * many bugfixes
  * code cleanup
- build DSSI object
* Fri Jan 18 2008 tiwai@suse.de
- fix strncat usage to avoid overflow.
* Thu Apr 26 2007 tiwai@suse.de
- fix buildrequires, use mxml-devel
- fix desktop file, use GenericName
* Mon Feb 26 2007 tiwai@suse.de
- fix array overflow (#247335)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Oct 12 2005 tiwai@suse.de
- removed glib* from neededforbuild.
* Wed Jul 27 2005 tiwai@suse.de
- updated to version 2.2.1.
* Fri Apr 15 2005 tiwai@suse.de
- updated to version 2.2.0.
- fixed for gcc-4.0.
* Fri Jan 21 2005 tiwai@suse.de
- updated to version 2.1.1.
  added desktop file again.
* Wed Sep 15 2004 tiwai@suse.de
- removed desktop file (not working from menu).
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Tue Nov 18 2003 tiwai@suse.de
- updated to version 1.4.3.
* Mon Sep 15 2003 tiwai@suse.de
- added desktop file and icon.
* Fri Jul 18 2003 tiwai@suse.de
- updated to version 1.4.2.
* Wed Jul  2 2003 tiwai@suse.de
- updated to version 1.4.1.
* Thu Mar 27 2003 tiwai@suse.de
- updated to version 1.2.0.
* Fri Feb 14 2003 tiwai@suse.de
- updated to version 1.0.8.
* Fri Feb  7 2003 tiwai@suse.de
- updated to version 1.0.7.
- linked with sfftw correctly now.
- fixed compile warnings.
* Wed Feb  5 2003 tiwai@suse.de
- initial version: 1.0.6.
